@@ -6,7 +6,7 @@
 #include <string>
 #include <vector>
 
-#include <bobcat/glob>
+#include "../../tmp/build/glob/glob"
 
 #include "../../tmp/build/builtinfunctions/builtinfunctions.h"
 
