@@ -4,7 +4,7 @@
 #include <fstream>
 #include <string>
 
-#include <bobcat/pattern>
+#include "../../tmp/build/pattern/pattern"
 
 #include "../classes/classes.h"
 
