@@ -7,7 +7,7 @@
 #include <filesystem>
 #include <unordered_set>
 
-#include <bobcat/exception>
+#include "../../tmp/build/exception/exception"
 
 namespace std
 {
